[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[or-cvs] cause configure to create a tor.sh which will have director...



Update of /home/or/cvsroot/src/or
In directory moria.mit.edu:/home/sah/src/or

Modified Files:
	config.c 
Log Message:
- cause configure to create a tor.sh which will have directories set
  correctly based on how configure was run

- cause tor to guess the location of torrc more intelligently

- cause cause src/config/torrc and src/conf/sample-server-torrc to be
  generated with contents that are correct for the way configure was
  run

- cause "make install" to put torrc, sample-server-torrc, and
  dirservers somewhere intelligent


Index: config.c
===================================================================
RCS file: /home/or/cvsroot/src/or/config.c,v
retrieving revision 1.57
retrieving revision 1.58
diff -u -d -r1.57 -r1.58
--- config.c	10 Oct 2003 01:48:31 -0000	1.57
+++ config.c	15 Oct 2003 07:19:38 -0000	1.58
@@ -220,8 +220,8 @@
   }
   if(i < argc-1) { /* we found one */
     fname = argv[i+1];
-  } else { /* didn't find one, try /etc/torrc */
-    fname = "/etc/torrc";
+  } else { /* didn't find one, try CONFDIR */
+    fname = CONFDIR "/torrc";
   }
   log(LOG_DEBUG,"Opening config file '%s'",fname);